@@ -16,8 +16,9 @@ class ResponseWrap(object):
     # 获得元素值
     def _get_val_by(self, type, path):
         if type == 'css':
-            html = etree.parse(self.res.text, etree.HTMLParser())
-            return html.cssselect(path).text
+            # html = etree.parse(self.res.text, etree.HTMLParser()) # parse的是html文件
+            html = etree.fromstring(self.res.text, etree.HTMLParser()) # fromstring的是html文本
+            return html.cssselect(path)[0].text
 
         if type == 'xpath':
             # 检查xpath是否最后有属性
@@ -29,8 +30,8 @@ class ResponseWrap(object):
                 path = path.replace(prop, '')
                 prop = prop.replace('/@', '')
 
-            html = etree.parse(self.res.text, etree.HTMLParser())
-            ele = html.xpath(path)
+            html = etree.fromstring(self.res.text, etree.HTMLParser())
+            ele = html.xpath(path)[0]
             if prop != '': # 获得属性
                 return ele.get(prop)
             return ele.text
